@@ -4,24 +4,28 @@
 
 "use strict";
 
-const Services = require("Services");
-const promise = require("promise");
-const { PSEUDO_CLASSES } = require("devtools/shared/css/constants");
-const { LocalizationHelper } = require("devtools/shared/l10n");
+const {
+  PSEUDO_CLASSES,
+} = require("resource://devtools/shared/css/constants.js");
+const { LocalizationHelper } = require("resource://devtools/shared/l10n.js");
 
-loader.lazyRequireGetter(this, "Menu", "devtools/client/framework/menu");
+loader.lazyRequireGetter(
+  this,
+  "Menu",
+  "resource://devtools/client/framework/menu.js"
+);
 loader.lazyRequireGetter(
   this,
   "MenuItem",
-  "devtools/client/framework/menu-item"
+  "resource://devtools/client/framework/menu-item.js"
 );
 loader.lazyRequireGetter(
   this,
   "clipboardHelper",
-  "devtools/shared/platform/clipboard"
+  "resource://devtools/shared/platform/clipboard.js"
 );
 
-loader.lazyGetter(this, "TOOLBOX_L10N", function() {
+loader.lazyGetter(this, "TOOLBOX_L10N", function () {
   return new LocalizationHelper("devtools/client/locales/toolbox.properties");
 });
 
@@ -55,7 +59,7 @@ class MarkupContextMenu {
 
   show(event) {
     if (
-      !(event.originalTarget instanceof Element) ||
+      !Element.isInstance(event.originalTarget) ||
       event.originalTarget.closest("input[type=text]") ||
       event.originalTarget.closest("input:not([type])") ||
       event.originalTarget.closest("textarea")
@@ -210,11 +214,8 @@ class MarkupContextMenu {
    * Jumps to the custom element definition in the debugger.
    */
   _jumpToCustomElementDefinition() {
-    const {
-      url,
-      line,
-      column,
-    } = this.selection.nodeFront.customElementLocation;
+    const { url, line, column } =
+      this.selection.nodeFront.customElementLocation;
     this.toolbox.viewSourceInDebugger(
       url,
       line,
@@ -287,7 +288,7 @@ class MarkupContextMenu {
   _pasteAdjacentHTML(position) {
     const content = this._getClipboardContentForPaste();
     if (!content) {
-      return promise.reject("No clipboard content for paste");
+      return Promise.reject("No clipboard content for paste");
     }
 
     const node = this.selection.nodeFront;
@@ -300,7 +301,7 @@ class MarkupContextMenu {
   _pasteInnerHTML() {
     const content = this._getClipboardContentForPaste();
     if (!content) {
-      return promise.reject("No clipboard content for paste");
+      return Promise.reject("No clipboard content for paste");
     }
 
     const node = this.selection.nodeFront;
@@ -315,7 +316,7 @@ class MarkupContextMenu {
   _pasteOuterHTML() {
     const content = this._getClipboardContentForPaste();
     if (!content) {
-      return promise.reject("No clipboard content for paste");
+      return Promise.reject("No clipboard content for paste");
     }
 
     const node = this.selection.nodeFront;
@@ -368,44 +369,13 @@ class MarkupContextMenu {
       "temp" + i;
     }`;
 
-    const res = await hud.evaluateJSAsync(evalString, {
+    const res = await this.toolbox.commands.scriptCommand.execute(evalString, {
       selectedNodeActor: this.selection.nodeFront.actorID,
     });
     hud.setInputValue(res.result);
     this.inspector.emit("console-var-ready");
   }
 
-  _buildA11YMenuItem(menu) {
-    if (
-      !(this.selection.isElementNode() || this.selection.isTextNode()) ||
-      !Services.prefs.getBoolPref("devtools.accessibility.enabled")
-    ) {
-      return;
-    }
-
-    const a11yAutoInitEnabled = Services.prefs.getBoolPref(
-      "devtools.accessibility.auto-init.enabled",
-      false
-    );
-    const showA11YPropsItem = new MenuItem({
-      id: "node-menu-showaccessibilityproperties",
-      label: INSPECTOR_L10N.getStr(
-        "inspectorShowAccessibilityProperties.label"
-      ),
-      click: () => this._showAccessibilityProperties(),
-      disabled: !a11yAutoInitEnabled,
-    });
-
-    // Only attempt to determine if a11y props menu item needs to be enabled if
-    // AccessibilityFront is enabled and accessibility panel auto init feature
-    // is disabled.
-    if (!a11yAutoInitEnabled && this.inspector.accessibilityFront.enabled) {
-      this._updateA11YMenuItem(showA11YPropsItem);
-    }
-
-    menu.append(showA11YPropsItem);
-  }
-
   _getAttributesSubmenu(isEditableElement) {
     const attributesSubmenu = new Menu();
     const nodeInfo = this.nodeMenuTriggerInfo;
@@ -469,7 +439,7 @@ class MarkupContextMenu {
    */
   _getClipboardContentForPaste() {
     const content = clipboardHelper.getText();
-    if (content && content.trim().length > 0) {
+    if (content && content.trim().length) {
       return content;
     }
     return null;
@@ -601,7 +571,7 @@ class MarkupContextMenu {
     const type = popupNode.dataset.type;
     if (type === "uri" || type === "cssresource" || type === "jsresource") {
       // Links can't be opened in new tabs in the browser toolbox.
-      if (type === "uri" && !this.target.chrome) {
+      if (type === "uri" && !this.toolbox.isBrowserToolbox) {
         linkFollow.visible = true;
         linkFollow.label = INSPECTOR_L10N.getStr(
           "inspector.menu.openUrlInNewTab.label"
@@ -737,6 +707,17 @@ class MarkupContextMenu {
     return menu;
   }
 
+  _getEditMarkupString() {
+    if (this.selection.isHTMLNode()) {
+      return "inspectorHTMLEdit";
+    } else if (this.selection.isSVGNode()) {
+      return "inspectorSVGEdit";
+    } else if (this.selection.isMathMLNode()) {
+      return "inspectorMathMLEdit";
+    }
+    return "inspectorXMLEdit";
+  }
+
   _openMenu({ target, screenX = 0, screenY = 0 } = {}) {
     if (this.selection.isSlotted()) {
       // Slotted elements should not show any context menu.
@@ -762,7 +743,7 @@ class MarkupContextMenu {
     menu.append(
       new MenuItem({
         id: "node-menu-edithtml",
-        label: INSPECTOR_L10N.getStr("inspectorHTMLEdit.label"),
+        label: INSPECTOR_L10N.getStr(`${this._getEditMarkupString()}.label`),
         accesskey: INSPECTOR_L10N.getStr("inspectorHTMLEdit.accesskey"),
         disabled: isAnonymous || (!isElement && !isFragment),
         click: () => this._editHTML(),
@@ -845,7 +826,17 @@ class MarkupContextMenu {
       })
     );
 
-    this._buildA11YMenuItem(menu);
+    if (this.selection.isElementNode() || this.selection.isTextNode()) {
+      menu.append(
+        new MenuItem({
+          id: "node-menu-showaccessibilityproperties",
+          label: INSPECTOR_L10N.getStr(
+            "inspectorShowAccessibilityProperties.label"
+          ),
+          click: () => this._showAccessibilityProperties(),
+        })
+      );
+    }
 
     if (this.selection.nodeFront.customElementLocation) {
       menu.append(
@@ -939,7 +930,7 @@ class MarkupContextMenu {
     );
 
     const nodeLinkMenuItems = this._getNodeLinkMenuItems();
-    if (nodeLinkMenuItems.filter(item => item.visible).length > 0) {
+    if (nodeLinkMenuItems.filter(item => item.visible).length) {
       menu.append(
         new MenuItem({
           id: "node-menu-link-separator",
@@ -955,19 +946,6 @@ class MarkupContextMenu {
     menu.popup(screenX, screenY, this.toolbox.doc);
     return menu;
   }
-
-  async _updateA11YMenuItem(menuItem) {
-    const hasA11YProps = await this.walker.hasAccessibilityProperties(
-      this.selection.nodeFront
-    );
-
-    if (hasA11YProps) {
-      const menuItemEl = Menu.getMenuElementById(menuItem.id, this.toolbox.doc);
-      menuItemEl.disabled = menuItem.disabled = false;
-    }
-
-    this.inspector.emit("node-menu-updated");
-  }
 }
 
 module.exports = MarkupContextMenu;
